@@ -178,7 +178,7 @@ class Property():
         if self.name == 'Source Text':
             self.value = (
                 'Syrian Observatory for Human Rights Facebook Page ' +
-                str(self.post.short_date)
+                self.post.date.strftime('%B %d %Y')
             )
 
         if self.name == 'Country Team':
@@ -204,6 +204,9 @@ class Property():
                 return ''
             elif answer == 'y':
                 print('\n' + self.y)
+            elif answer == 'r':
+                self.activity.restart = True
+                return ''
             else:
                 return answer
 
